## \file   Task1.py
#  \brief  compute summary measures for raw data 
#
#  \author OM
import sys
from MCS2012_lib import fetchData, getPmf, basicStatistics, bootstrap

def median(myList):
        """compute median for given sample

        Input:
        myList  - sample

        Returns: (med)
        med     - median value
        """
	myList.sort()
	N = len(myList)
	if N%2: # N odd
		return myList[N/2]
	else:   # N even
		return 0.5*(myList[N/2-1]+myList[N/2])

def medianAbsDev(myList):
        """compute median of absolut deviations from 
        the median 

        NOTE: robust measure for variability of the dataset

        Input:
        myList  - sample

        Returns: (mad)
        mad     - median absolute deviation
        """
        med = median(myList)
        return median(map(lambda x: abs(x-med),myList))

def mostProbLength(myList):
        """compute most probable path length

        Input:
        myList  - sample

        Returns: (pmaxLen)
        pmaxLen - most probable path length
        """
        pMax,x = max(map(lambda (x,p): (p,x),getPmf(myList).iteritems() ))
        return x

def listPmf(myPmf):
        """dump pmf to standard outstream

        Input:
        myPmf   - prob mass fct 

        Returns: (None)
        """
        print "# probability mass function"
        print "# n t(n)"
        for l,prob in sorted(myPmf.iteritems()):
	        print l,prob

print "# ",sys.argv

# read raw data from file
walkLengths = fetchData(sys.argv[1],0)
RList = fetchData(sys.argv[1],1,float)

# construct PMF
myPmf = getPmf(walkLengths)

# write PMF to stdout
#listPmf(myPmf)

print "# walk length summary measures:"
# basic summary measures
n_av,n_sDev,n_sErr = basicStatistics(walkLengths)
print "# n_av   =",n_av,"+-",n_sErr
print "# n_sDev =",n_sDev

# summary measures involving the median
n_med = median(walkLengths)
n_mad = medianAbsDev(walkLengths)
print "# n_med  =",n_med
print "# n_mad  =",n_mad

# most propable walk length
n_mostProb, n_mostProb_err = bootstrap(walkLengths,mostProbLength,20)
print "# n_tmax = ",n_mostProb,"+-",n_mostProb_err

# maximal length encountered
maxLen = max(walkLengths)
print "# n_max  =",maxLen

# average start-to-end distance
avR,sDevR,sErrR = basicStatistics(RList)
print "# R_av   =",avR,"+-", sErrR

# EOF: Task1.py
