## \file   Task2.py
#  \brief  compute summary measures from probability 
#          mass function (PMF)
#
#  \author OM
import sys
from MCS2012_lib import fetchData, basicStatistics, getPmf

def pmfAv(myPmf):
        """compute average using probability mass function (PMF)

        Input:
        myPmf   - probability mass function

        Returns: (av)
        av      - average computed from PMF
        """
        return sum(map(lambda (xi,pi): xi*pi,myPmf.iteritems()))

def pmfUVar(myPmf):
        """compute uncorrected variance using PMF 

        Input:
        myPmf   - probability mass function

        Returns: (uVar)
        uVar    - uncorrected var computed from PMF
        """
        av = pmfAv(myPmf)
        return sum(map(lambda (xi,pi): pi*(xi-av)**2,myPmf.iteritems()))
        
# fetch raw data from file
walkLengths = fetchData(sys.argv[1],0,int)

# METHOD 1: determine sample size and summary measures
N = len(walkLengths)
av,sDev,sErr = basicStatistics(walkLengths)
uVar = (float(N-1)/N)*sDev**2

# METHOD 2: determine summary measures from PMF
myPmf = getPmf(walkLengths)
av_pmf, uVar_pmf = pmfAv(myPmf),pmfUVar(myPmf)

# compare numerical values
print 'METHOD  : av(x)   uVar(x)'
print 'direct  :',av, uVar
print 'via pmf :',av_pmf,uVar_pmf

# EOF: Task2.py
