import sys
import random
from math import sqrt

# abbreviations for convenience
seed      = random.seed
pickOneOf = random.choice
permute	  = random.shuffle


class Walker:
	def __init__(self,dirList=[(0,1),(0,-1),(1,0),(-1,0)]):
		self.posList = []
		self.dim     = len(dirList[0])
		self.currPos = [0]*len(dirList[0])
		self.nSteps  = 0
		self.dirList = dirList

	def R(self):
		return sqrt(sum(map(lambda x: x*x, self.currPos)))
		

	def step(self):
	    # get a random permutation of local directions
	    localDirList = [locDir for locDir in self.dirList]
	    permute(localDirList)
	    while localDirList:
		# propose a step direction and compute new position
		myDir = localDirList.pop()
		newPos = [self.currPos[i]+myDir[i] for i in range(self.dim) ]
		# decide if step is accepted
		if newPos not in self.posList:
			self.posList.append(newPos)
			self.currPos = newPos
			self.nSteps +=1
			return 0
	    return 1

	def walk(self):
		# reset walker
		self.posList = []
		self.currPos = [0]*self.dim
		self.nSteps  = 0
		# perform walk
		while 1:
		  if self.step():
			  return self.nSteps,self.R()



def main_2D_4nbs():
	s0=int(sys.argv[1])
	ds=int(sys.argv[2])
	directions = [(0,1),(0,-1),(1,0),(-1,0)]

	w = Walker(directions)
	for s in range(s0,s0+ds):
		seed(s)
		nSteps,R = w.walk()
		print nSteps,R



def main_2Dtriangular():


	s0=int(sys.argv[1])
	ds=int(sys.argv[2])
	directions = [(-1,0),(0,-1),(-1,1),(1,0),(0,1),(1,-1)]

	w = Walker(directions)
	for s in range(s0,s0+ds):
		seed(s)
		nSteps,R = w.walk()
		print nSteps,R

def main_2D_8nbs():


	s0=int(sys.argv[1])
	ds=int(sys.argv[2])
	directions = [(-1,0),(0,-1),(-1,1),(-1,-1),(1,0),(0,1),(1,-1),(1,1)]

	w = Walker(directions)
	for s in range(s0,s0+ds):
		seed(s)
		nSteps,R = w.walk()
		print nSteps,R



main_2D_4nbs()
